@@ -1,6 +1,6 @@
 UPopips<-function(lambda, type=c("pareto","uniform","exponential"))
 {
-if(any(is.na(lambda))) warning("there are missing values in the lambda vector")
+if(any(is.na(lambda))) stop("there are missing values in the lambda vector")
 n=sum(lambda)
 if(!(type %in% c("pareto","uniform","exponential"))) stop("the type argument is wrong")
 omega=runif(n)
